==> aws-cdk-scala_2.12-0.6.0-sources.jar: io/burkard/cdk/services/amplifyuibuilder/cfnComponent/ComponentPropertyProperty.scala <==
package io.burkard.cdk.services.amplifyuibuilder.cfnComponent

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ComponentPropertyProperty {

  def apply(
    model: Option[String] = None,
    event: Option[String] = None,
    bindings: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.FormBindingsProperty] = None,
    concat: Option[List[_]] = None,
    userAttribute: Option[String] = None,
    importedValue: Option[String] = None,
    condition: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentConditionPropertyProperty] = None,
    bindingProperties: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyBindingPropertiesProperty] = None,
    configured: Option[Boolean] = None,
    `type`: Option[String] = None,
    defaultValue: Option[String] = None,
    collectionBindingProperties: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyBindingPropertiesProperty] = None,
    value: Option[String] = None
  ): software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyProperty =
    (new software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyProperty.Builder)
      .model(model.orNull)
      .event(event.orNull)
      .bindings(bindings.orNull)
      .concat(concat.map(_.asJava).orNull)
      .userAttribute(userAttribute.orNull)
      .importedValue(importedValue.orNull)
      .condition(condition.orNull)
      .bindingProperties(bindingProperties.orNull)
      .configured(configured.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .`type`(`type`.orNull)
      .defaultValue(defaultValue.orNull)
      .collectionBindingProperties(collectionBindingProperties.orNull)
      .value(value.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.10.0-sources.jar: io/burkard/cdk/services/amplifyuibuilder/cfnComponent/ComponentPropertyProperty.scala <==
package io.burkard.cdk.services.amplifyuibuilder.cfnComponent

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ComponentPropertyProperty {

  def apply(
    model: Option[String] = None,
    event: Option[String] = None,
    bindings: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.FormBindingsProperty] = None,
    concat: Option[List[_]] = None,
    userAttribute: Option[String] = None,
    importedValue: Option[String] = None,
    condition: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentConditionPropertyProperty] = None,
    bindingProperties: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyBindingPropertiesProperty] = None,
    configured: Option[Boolean] = None,
    `type`: Option[String] = None,
    defaultValue: Option[String] = None,
    collectionBindingProperties: Option[software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyBindingPropertiesProperty] = None,
    value: Option[String] = None
  ): software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyProperty =
    (new software.amazon.awscdk.services.amplifyuibuilder.CfnComponent.ComponentPropertyProperty.Builder)
      .model(model.orNull)
      .event(event.orNull)
      .bindings(bindings.orNull)
      .concat(concat.map(_.asJava).orNull)
      .userAttribute(userAttribute.orNull)
      .importedValue(importedValue.orNull)
      .condition(condition.orNull)
      .bindingProperties(bindingProperties.orNull)
      .configured(configured.map(Boolean.box).orNull)
      .`type`(`type`.orNull)
      .defaultValue(defaultValue.orNull)
      .collectionBindingProperties(collectionBindingProperties.orNull)
      .value(value.orNull)
      .build()
}
